/*

DESCRIPTION:    main include file for ISOBIAS evaluation project.

COPYRIGHT:      (c) 2022, Brian Cornell, all rights reserved.

 TARGET MCU:    PIC12F1571

HW REVISION:    220720

VERSION:        0.1

MODIFICATION HISTORY:

    25 Jul 22, BWC, initial development.


*/



/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 * Version constants & definitions.  Build number is defined in constant 
 * VERBUILD and maintained by shell script build.sh and included in build.h.
 *++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
#define VERMAJOR    0
#define VERMINOR    1


/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 * Necessary includes.  Build.h contains the build number constant which is
 * maintained by the makefile.
 *++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
#ifndef UINT_MAX
#include <limits.h>
#endif
#include "build.h"


/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 * Conditional compilation.  Uncomment directive to enable / disable features.
 *++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/

/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 * System clock & Watchdog Timer
 *++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
#define CFG_OSC_C       0x78            //16MHz, FOSC config word determines clock
#define CFG_WDT_CON     0x08            //Watchdog interval=16mS, off.


/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 * System wide constants & definitions.  Convention:  S_<TYPE>_<INFO>
 * Types:
 *  + AL=ALias
 *  + AR=ARray address
 *  + BL=boolean value
 *  + BP=bit position within a data object
 *  + CC=Calibration Constant
 *  + CD=command data
 *  + CH=character
 *  + DC=Duty Cycle
 *  + DF=Default value for a configurable parameter
 *  + EN=ENable bit
 *  + IN=INitializing value
 *  + LM=LiMiting operational value
 *  + OF=OFfset in an array, list, etc.
 *  + MK=bit MasK
 *  + MP=Peripheral port bit MaPping
 *  + QY=quantity (count) of something
 *  + RT=RaTio or scaling factor
 *  + SL=SeLection value
 *  + SZ=size of an object or data type
 *  + TM=TiMing
 *  + VL=VoLtage
 * 
 * Info is user defined and should be descriptive.
 *++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
#define S_TM_PWM_F          250000          //PWM frequency
#define S_TM_PWM_P          (_XTAL_FREQ/S_TM_PWM_F)
#define S_DC_RUN            (S_TM_PWM_P/2)  //50%
#define S_TM_INT            10              //# mS for system to stabilize at power-up


/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 * PERIPHERAL ALIASES.
 * 
 * Implementation specific.Used mostly outside of the Initialize function to 
 * help with readability and portability.
 *++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
#define S_AL_WDT_ENABLE     SWDTEN          //Watchdog enable bit


/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 * Port/pin configuration: I/O, analog/digital, slew rate, etc.
 *++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
//Pin peripheral mapping
#define IO_APFCON   0x60                    //CWGOUTA on RA5, CWGOUTB on RA4
//Port I/O: 1=input, 0=output
#define IO_PORTA    0x04
//Port Analog/Digital: 1=analog, 0=digital
#define AD_PORTA    0x00
//Port weak pull-up: 1=enabled, 0=disabled
#define WP_PORTA    0x04
//Open drain: 1=open drain, 0=push-pull
#define OD_PORTA    0x00
//Slew rate: 1=limited, 0=maximum
#define SR_PORTA    0x00
//Input level: 1=ST, 0=TLL
#define IL_PORTA    0x00
//Initial latch states: all outputs logic low
#define S_IN_PORTA  0x00


/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 * Configure 16-bit PWMs:
 * 1=CWG
 *++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
#define CFG_PWM_1_CON           0x80            //Enabled, active high, std mode
#define CFG_PWM_1_INTE          0x00            //No interrupts
#define CFG_PWM_1_CLK           0x01            //No prescale, clock=HFINTOSC
#define CFG_PWM_1_LDCON         0x80            //Load triggering is immediate
#define CFG_PWM_1_OFCON         0x00            //Independent run mode
#define CFG_PWM_1_PHASE         0x0000          //Phase count
#define CFG_PWM_1_DC            S_DC_RUN        //Duty cycle
#define CFG_PWM_1_PERIOD        S_TM_PWM_P      //Period (frequency)
#define CFG_PWM_1_OFFSET        0x0000          //Offset count
#define CFG_PWM_1_TIMER         0x0000          //Starting value for timer


/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 * Configure CWG.
 *++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
#define CFG_CWG_1_CON0          0xE1            //Enabled, A&B pins on, HFINTOSC
#define CFG_CWG_1_CON1          0xA2            //On auto-shutdown pins low, PWM1
#define CFG_CWG_1_CON2          0x80            //Shutdown
#define CFG_CWG_1_DBR           0x01            //Rising dead-band
#define CFG_CWG_1_DBF           0x01            //Falling dead-band


/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 * Function declarations.  See source file for explanation of each function.
 *++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
void main(void);
void Initialize(void);


/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 * Preprocessor checks.  Maintain at end of main include file.
 *++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/



//End of file